==> ldapjdk_5.1.0+dfsg1.orig.tar.xz: ldap-sdk-5.1.0/java-sdk/ldapsp/src/main/java/com/netscape/jndi/ldap/LdapContextFactory.java <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
package com.netscape.jndi.ldap;

import java.util.Enumeration;
import java.util.Hashtable;

import javax.naming.Context;
import javax.naming.NamingException;
import javax.naming.event.EventDirContext;
import javax.naming.spi.InitialContextFactory;

public class LdapContextFactory implements InitialContextFactory {

    public Context getInitialContext(Hashtable env) throws NamingException {
        Hashtable ctxEnv = (Hashtable)env.clone();

        // Read system properties as well. Add a system property to the
        // env if it's name start with "java.naming." and it is not already
        // present in the env (env has precedence over the System properties)
        for (Enumeration e = System.getProperties().keys(); e.hasMoreElements();) {
            String key = (String) e.nextElement();
            if (key.startsWith("java.naming.")||
                key.startsWith("com.netscape.")) {
                if (ctxEnv.get(key) == null) {
                    ctxEnv.put(key,System.getProperty(key));
                }
            }
        }

        EventDirContext ctx = new LdapContextImpl(ctxEnv);
        return ctx;
    }
}

==> ldapjdk_5.5.0+dfsg1.orig.tar.xz: ldap-sdk-5.5.0/java-sdk/ldapsp/src/main/java/com/netscape/jndi/ldap/LdapContextFactory.java <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
package com.netscape.jndi.ldap;

import java.util.Enumeration;
import java.util.Hashtable;

import javax.naming.Context;
import javax.naming.NamingException;
import javax.naming.event.EventDirContext;
import javax.naming.spi.InitialContextFactory;

public class LdapContextFactory implements InitialContextFactory {

    public Context getInitialContext(Hashtable<?, ?>  env) throws NamingException {
        Hashtable<Object, Object>  ctxEnv = (Hashtable<Object, Object>) env.clone();

        // Read system properties as well. Add a system property to the
        // env if it's name start with "java.naming." and it is not already
        // present in the env (env has precedence over the System properties)
        for (Enumeration<Object> e = System.getProperties().keys(); e.hasMoreElements();) {
            String key = (String) e.nextElement();
            if (key.startsWith("java.naming.")||
                key.startsWith("com.netscape.")) {
                if (ctxEnv.get(key) == null) {
                    ctxEnv.put(key,System.getProperty(key));
                }
            }
        }

        EventDirContext ctx = new LdapContextImpl(ctxEnv);
        return ctx;
    }
}
